@@ -1,7 +1,10 @@
-make_EPSG <- function(file=system.file("proj/epsg", package="rgdal")) {
-	epsg <- file(file, open="r")
-	n <- ceiling(length(readLines(epsg)) / 2)
-	close(epsg)
+make_EPSG <- function(file) {
+        if (missing(file)) {
+            tf <- tempfile()
+            n <- .Call("PROJcopyEPSG", tf, package="rgdal")
+            if (n > 0) file <- tf
+            else stop("Error opening epsg file")
+        }
 #	epsg <- file(system.file("proj/epsg", package="rgdal"), open="r")
 # report Michael Sumner 071017
 	epsg <- file(file, open="r")
